@@ -1,48 +1,44 @@
 package Specio::Constraint::AnyCan;
-{
-  $Specio::Constraint::AnyCan::VERSION = '0.08';
-}
-
+$Specio::Constraint::AnyCan::VERSION = '0.10';
 use strict;
 use warnings;
-use namespace::autoclean;
 
-use B ();
-use Scalar::Util;
+use B               ();
+use List::MoreUtils ();
+use Role::Tiny::With;
+use Scalar::Util ();
 use Specio::Library::Builtins;
+use Specio::OO;
 
-use Moose;
-
+use Specio::Constraint::Role::CanType;
 with 'Specio::Constraint::Role::CanType';
 
-my $Defined = t('Defined');
-has '+parent' => (
-    init_arg => undef,
-    default  => sub { $Defined },
-);
+{
+    my $Defined = t('Defined');
+    sub _build_parent { $Defined }
+}
 
-my $_inline_generator = sub {
-    my $self = shift;
-    my $val  = shift;
+{
+    my $_inline_generator = sub {
+        my $self = shift;
+        my $val  = shift;
 
-    return
-          '( Scalar::Util::blessed('
-        . $val
-        . ') || ( '
-        . " defined $val && ! ref $val ) )"
-        . ' && List::MoreUtils::all { '
-        . $val
-        . '->can($_) } ' . '( '
-        . ( join ', ', map { B::perlstring($_) } @{ $self->methods() } )
-        . ')';
-};
+        return
+              '( Scalar::Util::blessed('
+            . $val
+            . ') || ( '
+            . " defined $val && ! ref $val ) )"
+            . ' && List::MoreUtils::all { '
+            . $val
+            . '->can($_) } ' . '( '
+            . ( join ', ', map { B::perlstring($_) } @{ $self->methods() } )
+            . ')';
+    };
 
-has '+_inline_generator' => (
-    init_arg => undef,
-    default  => sub { $_inline_generator },
-);
+    sub _build_inline_generator { $_inline_generator }
+}
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->_ooify();
 
 1;
 
@@ -52,18 +48,20 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::AnyCan - A class for constraints which require a class name or object with a set of methods
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
-  my $type = Specio::Constraint::AnyCan->new(...);
-  print $_, "\n" for @{ $type->methods() };
+    my $type = Specio::Constraint::AnyCan->new(...);
+    print $_, "\n" for @{ $type->methods() };
 
 =head1 DESCRIPTION
 
@@ -106,7 +104,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
