@@ -1,47 +1,41 @@
 package Specio::Constraint::AnyIsa;
-{
-  $Specio::Constraint::AnyIsa::VERSION = '0.08';
-}
-
+$Specio::Constraint::AnyIsa::VERSION = '0.10';
 use strict;
 use warnings;
-use namespace::autoclean;
 
-use B                  ();
-use Devel::PartialDump ();
-use Scalar::Util       ();
+use B ();
+use Role::Tiny::With;
+use Scalar::Util ();
 use Specio::Library::Builtins;
+use Specio::OO;
 
-use Moose;
-
+use Specio::Constraint::Role::IsaType;
 with 'Specio::Constraint::Role::IsaType';
 
-my $Defined = t('Defined');
-has '+parent' => (
-    init_arg => undef,
-    default  => sub { $Defined },
-);
+{
+    my $Defined = t('Defined');
+    sub _build_parent { $Defined }
+}
 
-my $_inline_generator = sub {
-    my $self = shift;
-    my $val  = shift;
+{
+    my $_inline_generator = sub {
+        my $self = shift;
+        my $val  = shift;
 
-    return
-          '( Scalar::Util::blessed('
-        . $val
-        . ') || ( '
-        . " defined $val && ! ref $val ) ) && "
-        . $val
-        . '->isa('
-        . B::perlstring( $self->class ) . ')';
-};
+        return
+              '( Scalar::Util::blessed('
+            . $val
+            . ') || ( '
+            . " defined $val && ! ref $val ) ) && "
+            . $val
+            . '->isa('
+            . B::perlstring( $self->class ) . ')';
+    };
 
-has '+_inline_generator' => (
-    init_arg => undef,
-    default  => sub { $_inline_generator },
-);
+    sub _build_inline_generator { $_inline_generator }
+}
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->_ooify();
 
 1;
 
@@ -51,18 +45,20 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::AnyIsa - A class for constraints which require a class name or an object that inherit from a specific class
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
-  my $type = Specio::Constraint::AnyIsa->new(...);
-  print $type->class();
+    my $type = Specio::Constraint::AnyIsa->new(...);
+    print $type->class();
 
 =head1 DESCRIPTION
 
@@ -103,7 +99,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
