@@ -1,45 +1,39 @@
 package Specio::Constraint::ObjectIsa;
-{
-  $Specio::Constraint::ObjectIsa::VERSION = '0.08';
-}
-
+$Specio::Constraint::ObjectIsa::VERSION = '0.10';
 use strict;
 use warnings;
-use namespace::autoclean;
 
-use B                  ();
-use Devel::PartialDump ();
-use Scalar::Util       ();
+use B ();
+use Role::Tiny::With;
+use Scalar::Util ();
 use Specio::Library::Builtins;
+use Specio::OO;
 
-use Moose;
-
+use Specio::Constraint::Role::IsaType;
 with 'Specio::Constraint::Role::IsaType';
 
-my $Object = t('Object');
-has '+parent' => (
-    init_arg => undef,
-    default  => sub { $Object },
-);
+{
+    my $Object = t('Object');
+    sub _build_parent { $Object }
+}
 
-my $_inline_generator = sub {
-    my $self = shift;
-    my $val  = shift;
+{
+    my $_inline_generator = sub {
+        my $self = shift;
+        my $val  = shift;
 
-    return
-          'Scalar::Util::blessed('
-        . $val . ')' . ' && '
-        . $val
-        . '->isa('
-        . B::perlstring( $self->class ) . ')';
-};
+        return
+              'Scalar::Util::blessed('
+            . $val . ')' . ' && '
+            . $val
+            . '->isa('
+            . B::perlstring( $self->class ) . ')';
+    };
 
-has '+_inline_generator' => (
-    init_arg => undef,
-    default  => sub { $_inline_generator },
-);
+    sub _build_inline_generator { $_inline_generator }
+}
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->_ooify();
 
 1;
 
@@ -49,18 +43,20 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::ObjectIsa - A class for constraints which require an object that inherits from a specific class
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
-  my $type = Specio::Constraint::ObjectIsa->new(...);
-  print $type->class();
+    my $type = Specio::Constraint::ObjectIsa->new(...);
+    print $type->class();
 
 =head1 DESCRIPTION
 
@@ -101,7 +97,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
