@@ -1,33 +1,39 @@
 package Specio::Constraint::Parameterizable;
-{
-  $Specio::Constraint::Parameterizable::VERSION = '0.08';
-}
-
+$Specio::Constraint::Parameterizable::VERSION = '0.10';
 use strict;
 use warnings;
-use namespace::autoclean;
 
-use MooseX::Params::Validate qw( validated_list );
+use Carp qw( confess );
+use Role::Tiny::With;
 use Specio::Constraint::Parameterized;
 use Specio::DeclaredAt;
+use Specio::OO;
+use Specio::TypeChecks qw( does_role isa_class );
 
-use Moose;
-
+use Specio::Constraint::Role::Interface;
 with 'Specio::Constraint::Role::Interface';
 
-has _parameterized_constraint_generator => (
-    is        => 'ro',
-    isa       => 'CodeRef',
-    init_arg  => 'parameterized_constraint_generator',
-    predicate => '_has_parameterized_constraint_generator',
-);
+{
+    my $role_attrs = Specio::Constraint::Role::Interface::_attrs();
 
-has _parameterized_inline_generator => (
-    is        => 'ro',
-    isa       => 'CodeRef',
-    init_arg  => 'parameterized_inline_generator',
-    predicate => '_has_parameterized_inline_generator',
-);
+    my $attrs = {
+        %{$role_attrs},
+        _parameterized_constraint_generator => {
+            isa       => 'CodeRef',
+            init_arg  => 'parameterized_constraint_generator',
+            predicate => '_has_parameterized_constraint_generator',
+        },
+        _parameterized_inline_generator => {
+            isa       => 'CodeRef',
+            init_arg  => 'parameterized_inline_generator',
+            predicate => '_has_parameterized_inline_generator',
+        },
+    };
+
+    sub _attrs {
+        return $attrs;
+    }
+}
 
 sub BUILD {
     my $self = shift;
@@ -49,17 +55,19 @@ sub BUILD {
 
 sub parameterize {
     my $self = shift;
-    my ( $parameter, $declared_at ) = validated_list(
-        \@_,
-        of          => { does => 'Specio::Constraint::Role::Interface' },
-        declared_at => {
-            isa      => 'Specio::DeclaredAt',
-            optional => 1,
-        },
-    );
+    my %args = @_;
+
+    my ( $parameter, $declared_at ) = @args{qw( of declared_at)};
+    does_role( $parameter, 'Specio::Constraint::Role::Interface' )
+        or confess
+        'The "of" parameter passed to ->parameterize() must be an object which does the Specio::Constraint::Role::Interface role';
+
+    if ($declared_at) {
+        isa_class( $declared_at, 'Specio::DeclaredAt' )
+            or confess
+            'The "declared_at" parameter passed to ->parameterize() must be a Specio::DeclaredAt object';
+    }
 
-    # This isn't a default so as to avoid generating it even when the
-    # parameter is already set.
     $declared_at //= Specio::DeclaredAt->new_from_caller(1);
 
     my %p = (
@@ -80,7 +88,7 @@ sub parameterize {
     return Specio::Constraint::Parameterized->new(%p);
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->_ooify();
 
 1;
 
@@ -90,25 +98,29 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::Parameterizable - A class which represents parameterizable constraints
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
-  my $arrayref = t('ArrayRef');
+    my $arrayref = t('ArrayRef');
 
-  my $arrayref_of_int = $arrayref->parameterize( of => t('Int') );
+    my $arrayref_of_int = $arrayref->parameterize( of => t('Int') );
 
 =head1 DESCRIPTION
 
 This class implements the API for parameterizable types like C<ArrayRef> and
 C<Maybe>.
 
+=for Pod::Coverage BUILD
+
 =head1 API
 
 This class implements the same API as L<Specio::Constraint::Simple>, with a few
@@ -165,7 +177,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
