@@ -1,28 +1,30 @@
 package Specio::Constraint::Parameterized;
-{
-  $Specio::Constraint::Parameterized::VERSION = '0.08';
-}
-
+$Specio::Constraint::Parameterized::VERSION = '0.10';
 use strict;
 use warnings;
-use namespace::autoclean;
 
-use Specio::Constraint::Parameterized;
-
-use Moose;
+use Role::Tiny::With;
+use Specio::OO;
+use Storable qw( dclone );
 
+use Specio::Constraint::Role::Interface;
 with 'Specio::Constraint::Role::Interface';
 
-has '+parent' => (
-    isa      => 'Specio::Constraint::Parameterizable',
-    required => 1,
-);
+{
+    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
 
-has parameter => (
-    is       => 'ro',
-    does     => 'Specio::Constraint::Role::Interface',
-    required => 1,
-);
+    $attrs->{parent}{isa}      = 'Specio::Constraint::Parameterizable';
+    $attrs->{parent}{required} = 1;
+
+    $attrs->{parameter} = {
+        does     => 'Specio::Constraint::Role::Interface',
+        required => 1,
+    };
+
+    sub _attrs {
+        return $attrs;
+    }
+}
 
 sub can_be_inlined {
     my $self = shift;
@@ -38,7 +40,7 @@ sub type_parameter {
     shift->parameter();
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->_ooify();
 
 1;
 
@@ -48,27 +50,31 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::Parameterized - A class which represents parameterized constraints
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
-  my $arrayref = t('ArrayRef');
+    my $arrayref = t('ArrayRef');
 
-  my $arrayref_of_int = $arrayref->parameterize( of => t('Int') );
+    my $arrayref_of_int = $arrayref->parameterize( of => t('Int') );
 
-  my $parent = $arrayref_of_int->parent(); # returns ArrayRef
-  my $parameter = $arrayref_of_int->parameter(); # returns Int
+    my $parent = $arrayref_of_int->parent(); # returns ArrayRef
+    my $parameter = $arrayref_of_int->parameter(); # returns Int
 
 =head1 DESCRIPTION
 
 This class implements the API for parameterized types.
 
+=for Pod::Coverage can_be_inlined type_parameter
+
 =head1 API
 
 This class implements the same API as L<Specio::Constraint::Simple>, with a few
@@ -106,7 +112,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
