@@ -1,102 +1,92 @@
 package Specio::Constraint::Role::Interface;
-{
-  $Specio::Constraint::Role::Interface::VERSION = '0.08';
-}
-
+$Specio::Constraint::Role::Interface::VERSION = '0.10';
 use strict;
 use warnings;
-use namespace::autoclean;
 
+use Carp qw( confess );
+use Class::Method::Modifiers ();
 use Devel::PartialDump;
-use List::AllUtils qw( all any );
-use Sub::Name qw( subname );
-use Try::Tiny;
+use List::MoreUtils qw( all any );
 use Specio::Exception;
+use Specio::TypeChecks qw( is_CodeRef );
+use Sub::Quote qw( quote_sub );
+use Try::Tiny;
 
-use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
+use Role::Tiny;
 
-with 'MooseX::Clone', 'Specio::Role::Inlinable';
+use Specio::Role::Inlinable;
+with 'Specio::Role::Inlinable';
 
-has name => (
-    is        => 'ro',
-    isa       => 'Str',
-    predicate => '_has_name',
+use overload(
+    q{""}  => sub { $_[0] },
+    '&{}'  => '_subify',
+    'bool' => sub { 1 },
 );
 
-has parent => (
-    is        => 'ro',
-    does      => 'Specio::Constraint::Role::Interface',
-    predicate => '_has_parent',
-);
+{
+    my $role_attrs = Specio::Role::Inlinable::_attrs();
 
-has _constraint => (
-    is        => 'rw',
-    writer    => '_set_constraint',
-    isa       => 'CodeRef',
-    predicate => '_has_constraint',
-    init_arg  => 'constraint',
-);
+    my $attrs = {
+        %{$role_attrs},
+        name => {
+            is        => 'bare',
+            isa       => 'Str',
+            predicate => '_has_name',
+        },
+        parent => {
+            is        => 'bare',
+            does      => 'Specio::Constraint::Role::Interface',
+            predicate => '_has_parent',
+        },
+        _constraint => {
+            is        => 'bare',
+            isa       => 'CodeRef',
+            init_arg  => 'constraint',
+            predicate => '_has_constraint',
+        },
+        _optimized_constraint => {
+            is       => 'bare',
+            isa      => 'CodeRef',
+            init_arg => undef,
+            lazy     => 1,
+            builder  => '_build_optimized_constraint',
+        },
+        _ancestors => {
+            is       => 'bare',
+            isa      => 'ArrayRef',
+            init_arg => undef,
+            lazy     => 1,
+            builder  => '_build_ancestors',
+        },
+        _message_generator => {
+            is       => 'bare',
+            isa      => 'CodeRef',
+            init_arg => undef,
+        },
+        _coercions => {
+            is      => 'bare',
+            builder => '_build_coercions',
+        },
 
-has _optimized_constraint => (
-    is       => 'ro',
-    isa      => 'CodeRef',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => '_build_optimized_constraint',
-);
+        # Because types are cloned on import, we can't directly compare type
+        # objects. Because type names can be reused between packages (no global
+        # registry) we can't compare types based on name either.
+        _signature => {
+            is       => 'bare',
+            isa      => 'Str',
+            init_arg => undef,
+            lazy     => 1,
+            builder  => '_build_signature',
+        },
+    };
 
-has _ancestors => (
-    is       => 'ro',
-    isa      => 'ArrayRef',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => '_build_ancestors',
-);
-
-has _message_generator => (
-    is       => 'rw',
-    isa      => 'CodeRef',
-    init_arg => undef,
-);
-
-has _coercions => (
-    traits  => [ 'Clone', 'Hash' ],
-    handles => {
-        coercions               => 'values',
-        coercion_from_type      => 'get',
-        _has_coercion_from_type => 'exists',
-        _add_coercion           => 'set',
-        has_coercions           => 'count',
-    },
-    default => sub { {} },
-);
-
-# Because types are cloned on import, we can't directly compare type
-# objects. Because type names can be reused between packages (no global
-# registry) we can't compare types based on name either.
-has _signature => (
-    is       => 'ro',
-    isa      => 'Str',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => '_build_signature',
-);
+    sub _attrs {
+        return $attrs;
+    }
+}
 
 my $NullConstraint = sub { 1 };
 
-around BUILDARGS => sub {
-    my $orig  = shift;
-    my $class = shift;
-
-    my $p = $class->$orig(@_);
-
-    $p->{constraint}        = delete $p->{where}   if exists $p->{where};
-    $p->{message_generator} = delete $p->{message} if exists $p->{message};
-
-    return $p;
-};
-
 sub BUILD { }
 
 around BUILD => sub {
@@ -112,12 +102,19 @@ around BUILD => sub {
         'A type constraint should have either a constraint or inline_generator parameter, not both'
         if $self->_has_constraint() && $self->_has_inline_generator();
 
-    $self->_set_message_generator(
-        $self->_wrap_message_generator( $p->{message_generator} ) );
+    $self->{_message_generator}
+        = $self->_wrap_message_generator( $p->{message_generator} );
 
     return;
 };
 
+sub _set_constraint {
+    is_CodeRef( $_[1] )
+        or confess '_set_constraint() must be given a coderef, not a '
+        . Devel::PartialDump->new()->dump( $_[1] );
+    $_[0]->{_constraint} = $_[1];
+}
+
 sub _wrap_message_generator {
     my $self      = shift;
     my $generator = shift;
@@ -135,6 +132,12 @@ sub _wrap_message_generator {
     return sub { $generator->( $d, @_ ) };
 }
 
+sub coercions               { values %{ $_[0]->{coercions} } }
+sub coercion_from_type      { $_[0]->{coercions}{ $_[1] } }
+sub _has_coercion_from_type { exists $_[0]->{coercions}{ $_[1] } }
+sub _add_coercion           { $_[0]->{coercions}{ $_[1] } = $_[2] }
+sub has_coercions           { scalar keys %{ $_[0]->{coercions} } }
+
 sub validate_or_die {
     my $self  = shift;
     my $value = shift;
@@ -229,11 +232,9 @@ sub _constraint_with_parents {
 
     return $NullConstraint unless @constraints;
 
-    return subname(
-        'optimized constraint for ' . $self->_description() => sub {
-            all { $_->( $_[0] ) } @constraints;
-        }
-    );
+    return sub {
+        all { $_->( $_[0] ) } @constraints;
+    };
 }
 
 # This is only used for identifying from types as part of coercions, but I
@@ -314,14 +315,15 @@ sub can_inline_coercion_and_check {
             %env = ( %env, %{ $coercion->_inline_environment() } );
         }
 
-        #<<<
-        $source
-            .= $self->inline_check('$value')
-                . ' or Specio::Exception->throw( '
-                . ' message => ' . $message_generator_var_name . '->($value),'
-                . ' type    => ' . $type_var_name . ','
-                . ' value   => $value );';
-        #>>>
+        $source .= $self->inline_check('$value');
+        $source .= ' or ';
+        $source .= $self->_inline_throw_exception(
+            '$value',
+            $message_generator_var_name,
+            $type_var_name
+        );
+        $source .= ';';
+
         $source .= '$value };';
 
         $counter++;
@@ -330,6 +332,69 @@ sub can_inline_coercion_and_check {
     }
 }
 
+sub _subify {
+    my $self = shift;
+
+    if ( $self->can_be_inlined() ) {
+        my $inline = $self->inline_check('$_[0]');
+        $inline .= ' or ';
+
+        my %env = (
+            '$message_generator' => \( $self->_message_generator() ),
+            '$type'              => \$self,
+        );
+
+        $inline .= $self->_inline_throw_exception(
+            '$_[0]',
+            '$message_generator',
+            '$type',
+        );
+
+        return quote_sub( $inline, \%env );
+    }
+    else {
+        return sub { $self->validate_or_die( $_[0] ) };
+    }
+}
+
+sub _inline_throw_exception {
+    my $self                       = shift;
+    my $value_var                  = shift;
+    my $message_generator_var_name = shift;
+    my $type_var_name              = shift;
+
+    #<<<
+    return 'Specio::Exception->throw( '
+        . ' message => ' . $message_generator_var_name . '->(' . $value_var . '),'
+        . ' type    => ' . $type_var_name . ','
+        . ' value   => ' . $value_var . ' )';
+    #>>>
+}
+
+# This exists for the benefit of Moo
+sub coercion_sub {
+    my $self = shift;
+
+    if ( all { $_->can_be_inlined() } $self->coercions() ) {
+        my $inline = q{};
+        my %env;
+
+        for my $coercion ( $self->coercions() ) {
+            $inline
+                .= '$_[0] = '
+                . $coercion->inline_coercion( '$_[0]' ) . ' if '
+                . $coercion->from()->inline_check(' $_[0]' ) . ';';
+
+            %env = ( %env, %{ $coercion->_inline_environment() } );
+        }
+
+        return quote_sub( $inline, \%env );
+    }
+    else {
+        return sub { $self->coerce_value(shift) };
+    }
+}
+
 sub _build_ancestors {
     my $self = shift;
 
@@ -355,6 +420,8 @@ sub _build_description {
     return $desc;
 }
 
+sub _build_coercions { {} }
+
 sub _build_signature {
     my $self = shift;
 
@@ -392,7 +459,7 @@ sub _compiled_type_coercion {
 
     return sub {
         return $self->coerce_value(shift);
-        }
+    };
 }
 
 sub inline_environment {
@@ -430,13 +497,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::Role::Interface - The interface all type constraints should provide
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -445,6 +514,8 @@ provides most (or all) of the implementation. The L<Specio::Constraint::Simple>
 class simply consumes this role and provides no additional code. Other
 constraint classes add features or override some of this role's functionality.
 
+=for Pod::Coverage .*
+
 =head1 API
 
 See the L<Specio::Constraint::Simple> documentation for details. See the
@@ -453,7 +524,7 @@ or expanded upon.
 
 =head1 ROLES
 
-This role does the L<Specio::Role::Inlinable> and L<MooseX::Clone> roles.
+This role does the L<Specio::Role::Inlinable> role.
 
 =head1 AUTHOR
 
@@ -461,7 +532,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
