@@ -1,21 +1,32 @@
 package Specio::Constraint::Role::IsaType;
-{
-  $Specio::Constraint::Role::IsaType::VERSION = '0.08';
-}
-
+$Specio::Constraint::Role::IsaType::VERSION = '0.10';
 use strict;
 use warnings;
 
-use Moose::Role;
+use Storable qw( dclone );
 
-with 'Specio::Constraint::Role::Interface' =>
-    { -excludes => ['_wrap_message_generator'] };
+use Role::Tiny;
 
-has class => (
-    is       => 'ro',
-    isa      => 'ClassName',
-    required => 1,
-);
+use Specio::Constraint::Role::Interface;
+with 'Specio::Constraint::Role::Interface';
+
+{
+    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+
+    for my $name (qw( parent _inline_generator )) {
+        $attrs->{$name}{init_arg} = undef;
+        $attrs->{$name}{builder} = '_build_' . ( $name =~ s/^_//r );
+    }
+
+    $attrs->{class} = {
+        isa      => 'ClassName',
+        required => 1,
+    };
+
+    sub _attrs {
+        return $attrs;
+    }
+}
 
 sub _wrap_message_generator {
     my $self      = shift;
@@ -47,13 +58,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Specio::Constraint::Role::IsaType - Provides a common implementation for Specio::Constraint::AnyIsa and Specio::Constraint::ObjectIsa
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -65,7 +78,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
